@@ -790,7 +790,7 @@ class Dataset:
             sheet = workbook.add_worksheet(table.name)
             pointer = Pointer(0, 0)
             for field in table.fields:
-                sheet.write(pointer.row, pointer.col, field, workbook.add_format(sheet.header_style.attr()))
+                sheet.write(pointer.row, pointer.col, field, workbook.add_format(table.header_style.attr()))
                 pointer.next_col()
             pointer.next_row()
             for data_row in table.data_rows:
